pub fn parse_pytest_benchmark(
input: &str,
name: Option<&str>,
) -> Result<RunReceipt>Expand description
Parse a pytest-benchmark JSON file into a RunReceipt.
If the JSON contains multiple benchmarks, only the first is used.
All timing values in the input are in seconds and are converted
to milliseconds for the wall_ms metric.